# Changelog

## [2.0.0](https://github.com/nikoheikkila/semmy/compare/1.0.0...v2.0.0) (2025-09-04)


### ⚠ BREAKING CHANGES

* Drops support for older Python versions while migrating to `uv`.

### ✨ Features

* migrate to uv and modern Python ([4434182](https://github.com/nikoheikkila/semmy/commit/4434182324e9ec37e282222e2d95247f0dc89a22))


### 🐛 Bug Fixes

* **ci:** add API token to Task installation step ([782a45f](https://github.com/nikoheikkila/semmy/commit/782a45f7c6dcfd011bf04c0dc996cc146acbe146))
* use correct release numbering ([ace6a01](https://github.com/nikoheikkila/semmy/commit/ace6a01666e48d79b0f2f7391a3e5747b79d98c0))


### ♻️ Code Refactoring

* **tests:** improve unit test readability with assertpy ([889df60](https://github.com/nikoheikkila/semmy/commit/889df60accf9e7d445c122fc04a5173982fb7fe0))
